@@ -19,7 +19,7 @@ def resource_type_argument(command: Callable) -> Callable:
 
 
 def fides_key_argument(command: Callable) -> Callable:
-    "Add the id argument."
+    "Add the fides_key argument."
     command = click.argument(
         "fides_key",
         type=str,
@@ -27,11 +27,23 @@ def fides_key_argument(command: Callable) -> Callable:
     return command
 
 
+def fides_key_option(command: Callable) -> Callable:
+    "Add the fides_key option."
+    command = click.option(
+        "-k",
+        "--fides-key",
+        default="",
+        help="The fides_key of the single policy that you wish to evaluate.",
+    )(command)
+    return command
+
+
 def manifests_dir_argument(command: Callable) -> Callable:
-    "Add the id argument."
+    "Add the manifests_dir argument."
     command = click.argument(
         "manifests_dir",
-        type=click.Path(),
+        default=".fides/",
+        type=click.Path(exists=True),
     )(command)
     return command
 
